@@ -11,6 +11,7 @@ from __future__ import unicode_literals
 import xml.dom
 from . import basetest
 import css_parser
+import sys
 
 
 class SelectorTestCase(basetest.BaseTestCase):
@@ -412,7 +413,9 @@ class SelectorTestCase(basetest.BaseTestCase):
 
         # readonly
         def _set(): selector.specificity = 1
-        self.assertRaisesMsgSubstring(AttributeError, "can't set attribute", _set)
+
+        pattern = "object has no setter" if sys.version_info >= (3,11) else "can't set attribute"
+        self.assertRaisesMsgSubstring(AttributeError, pattern, _set)
 
         tests = {
             '*': (0, 0, 0, 0),
@@ -486,11 +489,11 @@ class SelectorTestCase(basetest.BaseTestCase):
 
         s = css_parser.css.Selector(selectorText=sel)
 
-        self.assertTrue(sel in str(s))
+        self.assertIn(sel, str(s))
 
         s2 = eval(repr(s))
-        self.assertTrue(isinstance(s2, s.__class__))
-        self.assertTrue(sel == s2.selectorText)
+        self.assertIsInstance(s2, s.__class__)
+        self.assertEqual(sel, s2.selectorText)
 
 
 if __name__ == '__main__':
